#!/usr/bin/env python
# Copyright (C) 2010 W. Trevor King <wking@drexel.edu>
#
# This file is part of SiteCorePy.
#
# SiteCorePy is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 2 of the License, or (at your
# option) any later version.
#
# SiteCorePy is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with SiteCorePy.  If not, see <http://www.gnu.org/licenses/>.

"""Move Professors from YAML -> Sitecore.

Professors will be created in:
  Content -> Drexel -> ? -> physics -> ?
"""

import time

from selenium.common.exceptions import NoSuchElementException
import yaml

from .. import SiteCoreConnection
from . import Name, Graduation, Contact, Bio, Professor


class ProfessorAdder (object):
    """See doc/faculty.txt for Drexel's field/format policy.
    """
    def __init__(self, sitecore_connection):
        self.s = sitecore_connection

    def setup(self):
        #self.s.expand_nav_section('sitecore')
        #self.s.expand_nav_section('Content')
        self.s.expand_nav_section('Home')
        for i in range(5): # 'physics' takes a while to load
            try:
                self.s.expand_nav_section('physics')
            except NoSuchElementException, e:
                time.sleep(self.s.wait_time)
        self.s.expand_nav_section('contact')
        self.s.expand_nav_section('facultyDirectory')

    def __call__(self, prof):
        self.create_prof_page(prof)
        self.s.open_nav_section(raw_name)
        TODO

    def create_prof_page(self, prof):
        self.s.open_nav_section('Copy of Shyamalendu Bose')
        self.s.w.find_element_by_link_text('Copy To').click()
        time.sleep(self.s.wait_time)
        windows = self.s.w.get_window_handles()
        current_window = self.s.w.get_current_window_handle()
        self.s.logger.info('handling copy popup %s (from %s)'
                         % (current_window, windows))
        name = self.s.find_element_by_id('Filename')
        name.clear()
        name.send_keys(
            '/sitecore/content/Home/physics/contact/facultyDirectory/%s %s'
            % (prof.name.first, prof.name.last))
        self.s.w.find_element_by_link_text('Copy').click()
        time.sleep(self.s.wait_time)


def main(argv):
    import optparse
    usage = """%prog [options] PROF_FILE

Where PROF_FILE is a YAML file containing professor data.

Example setup before running:
  Xvfb :99 > /dev/null 2>&1 &
  export DISPLAY=:99
  java -jar selenium-server-1.0.2-SNAPSHOT-standalone.jar > /dev/null 2>&1 &
  ./sc.py prof-import profs.yaml
"""
    p = optparse.OptionParser(usage)
    p.add_option('-u', '--url', metavar='URL', dest='url',
                 help='set the website URL (%default)',
                 default='https://webedit.drexel.edu/sitecore/login')
    p.add_option('-v', '--verbose', dest='verbose', action='count',
                 help='increment verbosity (%default)',
                 default=0)

    options,args = p.parse_args(argv[1:])
    prof_file = args[0]
    profs = yaml.load(prof_file)

    s = SiteCoreConnection(options.url, options.verbose)
    s.start()
    try:
        s.login()
        add = ProfessorAdder(s)
        add.setup()
        for prof in profs:
            add(prof)
    finally:
        s.stop()
